==> haskell-parsers-0.12.9-23-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-parsers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: parsers
version: 0.12.9
id: parsers-0.12.9-Po1tMMIUkHKvRrjv3h6q7
key: parsers-0.12.9-Po1tMMIUkHKvRrjv3h6q7
license: BSD-3-Clause
copyright: Copyright (C) 2010-2013 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: experimental
homepage: http://github.com/ekmett/parsers/
synopsis: Parsing combinators
description:
    This library provides convenient combinators for working with and building parsing combinator libraries.
    .
    Given a few simple instances, e.g. for the class '\''Text.Parser.Combinators.Parsing'\'' in "Text.Parser.Combinators.Parsing" you
    get access to a large number of canned definitions. Instances exist for the parsers provided by @parsec@,
    @attoparsec@ and base’s "Text.Read".
category: Text, Parsing
abi: 75d4a45d602b51d63c57a0207e9bfd5a
exposed: True
exposed-modules:
    Text.Parser.Char Text.Parser.Combinators Text.Parser.Expression
    Text.Parser.LookAhead Text.Parser.Permutation Text.Parser.Token
    Text.Parser.Token.Highlight Text.Parser.Token.Style
import-dirs: /usr/lib/ghc-8.6.4/site-local/parsers-0.12.9
library-dirs: /usr/lib/ghc-8.6.4/site-local/parsers-0.12.9
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/parsers-0.12.9
hs-libraries: HSparsers-0.12.9-Po1tMMIUkHKvRrjv3h6q7
depends:
    attoparsec-0.13.2.2-6cOh3sci63HJyadcbPhvpT base-4.12.0.0
    base-orphans-0.8-7pByK7w1VGecEyVBPbOH binary-0.8.6.0
    charset-0.3.7.1-IScnJFtw5PtlN6mv65WbN containers-0.6.0.1 mtl-2.2.2
    parsec-3.1.13.0 scientific-0.3.6.2-BVEhLkswVxa6jxFFJ9XwaR
    text-1.2.3.1 transformers-0.5.6.2
    unordered-containers-0.2.10.0-5bnYBnE7Vkj9Kd62fWith8
haddock-interfaces: /usr/share/doc/haskell-parsers/html/parsers.haddock
haddock-html: /usr/share/doc/haskell-parsers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-parsers-0.12.9-24-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-parsers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: parsers
version: 0.12.9
id: parsers-0.12.9-8MpPC3g7g67EaswPFtvpZs
key: parsers-0.12.9-8MpPC3g7g67EaswPFtvpZs
license: BSD-3-Clause
copyright: Copyright (C) 2010-2013 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: experimental
homepage: http://github.com/ekmett/parsers/
synopsis: Parsing combinators
description:
    This library provides convenient combinators for working with and building parsing combinator libraries.
    .
    Given a few simple instances, e.g. for the class '\''Text.Parser.Combinators.Parsing'\'' in "Text.Parser.Combinators.Parsing" you
    get access to a large number of canned definitions. Instances exist for the parsers provided by @parsec@,
    @attoparsec@ and base’s "Text.Read".
category: Text, Parsing
abi: 8c83a617d95e14f87c6a013eb7fa91b0
exposed: True
exposed-modules:
    Text.Parser.Char Text.Parser.Combinators Text.Parser.Expression
    Text.Parser.LookAhead Text.Parser.Permutation Text.Parser.Token
    Text.Parser.Token.Highlight Text.Parser.Token.Style
import-dirs: /usr/lib/ghc-8.6.4/site-local/parsers-0.12.9
library-dirs: /usr/lib/ghc-8.6.4/site-local/parsers-0.12.9
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/parsers-0.12.9
hs-libraries: HSparsers-0.12.9-8MpPC3g7g67EaswPFtvpZs
depends:
    attoparsec-0.13.2.2-6cOh3sci63HJyadcbPhvpT base-4.12.0.0
    base-orphans-0.8-3qkwKrVzBSN1odhlyV1Iin binary-0.8.6.0
    charset-0.3.7.1-IScnJFtw5PtlN6mv65WbN containers-0.6.0.1 mtl-2.2.2
    parsec-3.1.13.0 scientific-0.3.6.2-BVEhLkswVxa6jxFFJ9XwaR
    text-1.2.3.1 transformers-0.5.6.2
    unordered-containers-0.2.10.0-5bnYBnE7Vkj9Kd62fWith8
haddock-interfaces: /usr/share/doc/haskell-parsers/html/parsers.haddock
haddock-html: /usr/share/doc/haskell-parsers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
